pub enum LineCap {
Butt,
Square,
Round,
}Available on crate feature
canvas only.Expand description
The shape used at the end of open subpaths when they are stroked.
Variants
Butt
The stroke for each sub-path does not extend beyond its two endpoints.
Square
At the end of each sub-path, the shape representing the stroke will be extended by a square.
Round
At the end of each sub-path, the shape representing the stroke will be extended by a semicircle.