pub struct PathSlice<'l> { /* private fields */ }Available on crate feature
canvas only.Expand description
A view on a Path.
Implementations
Sourceimpl<'l> PathSlice<'l>
An immutable view over a Path.
impl<'l> PathSlice<'l>
An immutable view over a Path.
pub fn first_endpoint(&self) -> Option<(Point2D<f32, UnknownUnit>, &'l [f32])>
pub fn last_endpoint(&self) -> Option<(Point2D<f32, UnknownUnit>, &'l [f32])>
Sourcepub fn id_iter(&self) -> IdIter<'_> ⓘ
pub fn id_iter(&self) -> IdIter<'_> ⓘ
Iterates over the endpoint and control point ids of the Path.
Sourcepub fn iter_with_attributes(&self) -> IterWithAttributes<'_> ⓘ
pub fn iter_with_attributes(&self) -> IterWithAttributes<'_> ⓘ
Iterates over the entire Path with custom attributes.
pub fn is_empty(&self) -> bool
Sourcepub fn attributes(&self, endpoint: EndpointId) -> &'l [f32]
pub fn attributes(&self, endpoint: EndpointId) -> &'l [f32]
Returns a slice over an endpoint’s custom attributes.
Sourcepub fn reversed(&self) -> NoAttributes<Reversed<'_>> ⓘ
pub fn reversed(&self) -> NoAttributes<Reversed<'_>> ⓘ
Returns a reversed version of this path in the form of an iterator