pub struct Fill {
pub style: Style,
pub rule: Rule,
}Available on crate feature
canvas only.Expand description
The style used to fill geometry.
Fields
style: StyleThe color or gradient of the fill.
By default, it is set to Style::Solid with Color::BLACK.
rule: RuleThe fill rule defines how to determine what is inside and what is outside of a shape.
See the SVG specification for more details.
By default, it is set to NonZero.