Checkbox

Struct Checkbox 

pub struct Checkbox<'a, Message, Theme = Theme, Renderer = Renderer>
where Renderer: Renderer, Theme: Catalog,
{ /* private fields */ }
A box that can be checked.

Example

use iced::widget::checkbox;

struct State {
   is_checked: bool,
}

enum Message {
    CheckboxToggled(bool),
}

fn view(state: &State) -> Element<'_, Message> {
    checkbox(state.is_checked)
        .label("Toggle me!")
        .on_toggle(Message::CheckboxToggled)
        .into()
}

fn update(state: &mut State, message: Message) {
    match message {
        Message::CheckboxToggled(is_checked) => {
            state.is_checked = is_checked;
        }
    }
}

Checkbox drawn by iced_wgpu

Implementations

Source

impl<'a, Message, Theme, Renderer> Checkbox<'a, Message, Theme, Renderer>
where Renderer: Renderer, Theme: Catalog,

pub fn new(is_checked: bool) -> Self

Creates a new Checkbox.

It expects:

  • a boolean describing whether the Checkbox is checked or not
pub fn label(self, label: impl IntoFragment<'a>) -> Self

Sets the label of the Checkbox.

pub fn on_toggle<F>(self, f: F) -> Self
where F: 'a + Fn(bool) -> Message,

Sets the function that will be called when the Checkbox is toggled. It will receive the new state of the Checkbox and must produce a Message.

Unless on_toggle is called, the Checkbox will be disabled.

pub fn on_toggle_maybe<F>(self, f: Option<F>) -> Self
where F: Fn(bool) -> Message + 'a,

Sets the function that will be called when the Checkbox is toggled, if Some.

If None, the checkbox will be disabled.

pub fn size(self, size: impl Into<Pixels>) -> Self

Sets the size of the Checkbox.

pub fn width(self, width: impl Into<Length>) -> Self

Sets the width of the Checkbox.

pub fn spacing(self, spacing: impl Into<Pixels>) -> Self

Sets the spacing between the Checkbox and the text.

pub fn text_size(self, text_size: impl Into<Pixels>) -> Self

Sets the text size of the Checkbox.

pub fn line_height(self, line_height: impl Into<LineHeight>) -> Self

Sets the text text::LineHeight of the Checkbox.

pub fn shaping(self, shaping: Shaping) -> Self

Sets the text::Shaping strategy of the Checkbox.

pub fn wrapping(self, wrapping: Wrapping) -> Self

Sets the text::Wrapping strategy of the Checkbox.

pub fn font(self, font: impl Into<Renderer::Font>) -> Self

Sets the Renderer::Font of the text of the Checkbox.

pub fn icon(self, icon: Icon<Renderer::Font>) -> Self

Sets the Icon of the Checkbox.

pub fn style(self, style: impl Fn(&Theme, Status) -> Style + 'a) -> Self
where Theme::Class<'a>: From<StyleFn<'a, Theme>>,

Sets the style of the Checkbox.

pub fn class(self, class: impl Into<Theme::Class<'a>>) -> Self

Available on crate feature advanced only.

Sets the style class of the Checkbox.