Float

Struct Float 

pub struct Float<'a, Message, Theme = Theme, Renderer = Renderer>
where Theme: Catalog,
{ /* private fields */ }
A widget that can make its contents float over other widgets.

Implementations

Source

impl<'a, Message, Theme, Renderer> Float<'a, Message, Theme, Renderer>
where Theme: Catalog,

pub fn new(content: impl Into<Element<'a, Message, Theme, Renderer>>) -> Self

Creates a new Float widget with the given content.

pub fn scale(self, scale: f32) -> Self

Sets the scale to be applied to the contents of the Float.

pub fn translate( self, translate: impl Fn(Rectangle, Rectangle) -> Vector + 'a, ) -> Self

Sets the translation logic to be applied to the contents of the Float.

The logic takes the original (non-scaled) bounds of the contents and the viewport bounds. These bounds can be useful to ensure the floating elements always stay on screen.

pub fn style(self, style: impl Fn(&Theme) -> Style + 'a) -> Self
where Theme::Class<'a>: From<StyleFn<'a, Theme>>,

Sets the style of the Float.

pub fn class(self, class: impl Into<Theme::Class<'a>>) -> Self

Available on crate feature advanced only.

Sets the style class of the Float.