Sizing

Enum Sizing 

pub enum Sizing {
    AspectRatio(f32),
    EvenlyDistribute(Length),
}
The sizing strategy of a Grid.

Variants



AspectRatio(f32)

The Grid will ensure each cell follows the given aspect ratio and the total size will be the sum of the cells and the spacing between them.

The ratio is the amount of horizontal pixels per each vertical pixel of a cell in the Grid.



EvenlyDistribute(Length)

The Grid will evenly distribute the space available in the given Length for each cell.