Grid

Struct Grid 

pub struct Grid<'a, Message, Theme = Theme, Renderer = Renderer> { /* private fields */ }
A container that distributes its contents on a responsive grid.

Implementations

Source

impl<'a, Message, Theme, Renderer> Grid<'a, Message, Theme, Renderer>
where Renderer: Renderer,

pub fn new() -> Self

Creates an empty Grid.

pub fn with_capacity(capacity: usize) -> Self

Creates a Grid with the given capacity.

pub fn with_children( children: impl IntoIterator<Item = Element<'a, Message, Theme, Renderer>>, ) -> Self

Creates a Grid with the given elements.

pub fn from_vec(children: Vec<Element<'a, Message, Theme, Renderer>>) -> Self

Creates a Grid from an already allocated Vec.

pub fn spacing(self, amount: impl Into<Pixels>) -> Self

Sets the spacing between cells in the Grid.

pub fn width(self, width: impl Into<Pixels>) -> Self

Sets the width of the Grid in Pixels.

By default, a Grid will Fill its parent.

pub fn height(self, height: impl Into<Sizing>) -> Self

Sets the height of the Grid.

By default, a Grid uses a cell aspect ratio of 1.0 (i.e. squares).

pub fn columns(self, column: usize) -> Self

Sets the amount of columns in the Grid.

pub fn fluid(self, max_width: impl Into<Pixels>) -> Self

Makes the amount of columns dynamic in the Grid, never exceeding the provided max_width.

pub fn push( self, child: impl Into<Element<'a, Message, Theme, Renderer>>, ) -> Self

Adds an Element to the Grid.

pub fn push_maybe( self, child: Option<impl Into<Element<'a, Message, Theme, Renderer>>>, ) -> Self

Adds an element to the Grid, if Some.

pub fn extend( self, children: impl IntoIterator<Item = Element<'a, Message, Theme, Renderer>>, ) -> Self

Extends the Grid with the given children.