pub struct Viewer<Handle> { /* private fields */ }Available on crate feature
image only.Expand description
A frame that displays an image with the ability to zoom in/out and pan.
Implementations
Sourceimpl<Handle> Viewer<Handle>
impl<Handle> Viewer<Handle>
Sourcepub fn filter_method(self, filter_method: FilterMethod) -> Self
pub fn filter_method(self, filter_method: FilterMethod) -> Self
Sets the FilterMethod of the Viewer.
Sourcepub fn content_fit(self, content_fit: ContentFit) -> Self
pub fn content_fit(self, content_fit: ContentFit) -> Self
Sets the ContentFit of the Viewer.
Sourcepub fn max_scale(self, max_scale: f32) -> Self
pub fn max_scale(self, max_scale: f32) -> Self
Sets the max scale applied to the image of the Viewer.
Default is 10.0
Sourcepub fn min_scale(self, min_scale: f32) -> Self
pub fn min_scale(self, min_scale: f32) -> Self
Sets the min scale applied to the image of the Viewer.
Default is 0.25
Sourcepub fn scale_step(self, scale_step: f32) -> Self
pub fn scale_step(self, scale_step: f32) -> Self
Sets the percentage the image of the Viewer will be scaled by
when zoomed in / out.
Default is 0.10