Settings

Struct Settings 

pub struct Settings {
    pub text_size: Pixels,
    pub h1_size: Pixels,
    pub h2_size: Pixels,
    pub h3_size: Pixels,
    pub h4_size: Pixels,
    pub h5_size: Pixels,
    pub h6_size: Pixels,
    pub code_size: Pixels,
    pub spacing: Pixels,
    pub style: Style,
}
Available on crate feature markdown only.
Configuration controlling Markdown rendering in view.

Fields

text_size: Pixels

The base text size.

h1_size: Pixels

The text size of level 1 heading.

h2_size: Pixels

The text size of level 2 heading.

h3_size: Pixels

The text size of level 3 heading.

h4_size: Pixels

The text size of level 4 heading.

h5_size: Pixels

The text size of level 5 heading.

h6_size: Pixels

The text size of level 6 heading.

code_size: Pixels

The text size used in code blocks.

spacing: Pixels

The spacing to be used between elements.

style: Style

The styling of the Markdown.

Implementations

Source

impl Settings

pub fn with_style(style: impl Into<Style>) -> Self

Creates new Settings with default text size and the given Style.

pub fn with_text_size( text_size: impl Into<Pixels>, style: impl Into<Style>, ) -> Self

Creates new Settings with the given base text size in Pixels.

Heading levels will be adjusted automatically. Specifically, the first level will be twice the base size, and then every level after that will be 25% smaller.