pub struct Style {
pub font: Font,
pub inline_code_highlight: Highlight,
pub inline_code_padding: Padding,
pub inline_code_color: Color,
pub inline_code_font: Font,
pub code_block_font: Font,
pub link_color: Color,
}Available on crate feature
markdown only.Expand description
The text styling of some Markdown rendering in view.
Fields
font: FontThe Font to be applied to basic text.
inline_code_highlight: HighlightThe Highlight to be applied to the background of inline code.
inline_code_padding: PaddingThe Padding to be applied to the background of inline code.
inline_code_color: ColorThe Color to be applied to inline code.
inline_code_font: FontThe Font to be applied to inline code.
code_block_font: FontThe Font to be applied to code blocks.
link_color: ColorThe Color to be applied to links.
Implementations
Sourceimpl Style
impl Style
Sourcepub fn from_palette(seed: Seed) -> Self
pub fn from_palette(seed: Seed) -> Self
Creates a new Style from the given palette::Seed.