Menu

Struct Menu 

pub struct Menu<'a, 'b, T, Message, Theme = Theme, Renderer = Renderer>
where Theme: Catalog, Renderer: Renderer, 'b: 'a,
{ /* private fields */ }
A list of selectable options.

Implementations

Source

impl<'a, 'b, T, Message, Theme, Renderer> Menu<'a, 'b, T, Message, Theme, Renderer>
where T: ToString + Clone, Message: 'a, Theme: Catalog + 'a, Renderer: Renderer + 'a, 'b: 'a,

pub fn new( state: &'a mut State, options: &'a [T], hovered_option: &'a mut Option<usize>, on_selected: impl FnMut(T) -> Message + 'a, on_option_hovered: Option<&'a dyn Fn(T) -> Message>, class: &'a <Theme as Catalog>::Class<'b>, ) -> Self

Creates a new Menu with the given State, a list of options, the message to produced when an option is selected, and its Style.

pub fn width(self, width: f32) -> Self

Sets the width of the Menu.

pub fn padding<P: Into<Padding>>(self, padding: P) -> Self

Sets the Padding of the Menu.

pub fn text_size(self, text_size: impl Into<Pixels>) -> Self

Sets the text size of the Menu.

pub fn text_line_height(self, line_height: impl Into<LineHeight>) -> Self

Sets the text text::LineHeight of the Menu.

pub fn text_shaping(self, shaping: Shaping) -> Self

Sets the text::Shaping strategy of the Menu.

pub fn font(self, font: impl Into<Renderer::Font>) -> Self

Sets the font of the Menu.

pub fn overlay( self, position: Point, viewport: Rectangle, target_height: f32, menu_height: Length, ) -> Element<'a, Message, Theme, Renderer>

Turns the Menu into an overlay Element at the given target position.

The target_height will be used to display the menu either on top of the target or under it, depending on the screen position and the dimensions of the Menu.