pub struct Style {
pub background: Background,
pub border: Border,
pub text_color: Color,
pub selected_text_color: Color,
pub selected_background: Background,
pub shadow: Shadow,
}Expand description
The appearance of a Menu.
Fields
background: BackgroundThe Background of the menu.
border: BorderThe Border of the menu.
text_color: ColorThe text Color of the menu.
selected_text_color: ColorThe text Color of a selected option in the menu.
selected_background: BackgroundThe background Color of a selected option in the menu.
shadow: ShadowThe Shadow of the menu.