Node

Enum Node 

pub enum Node {
    Split {
        id: Split,
        axis: Axis,
        ratio: f32,
        a: Box<Node>,
        b: Box<Node>,
    },
    Pane(Pane),
}
A layout node of a PaneGrid.

Variants



Split

The region of this Node is split into two.

Fields

id: Split

The Split of this Node.

axis: Axis

The direction of the split.

ratio: f32

The ratio of the split in [0.0, 1.0].

a: Box<Node>

The left/top Node of the split.

b: Box<Node>

The right/bottom Node of the split.



Pane(Pane)

The region of this Node is taken by a Pane.

Implementations

Source

impl Node

pub fn splits(&self) -> impl Iterator<Item = &Split>

Returns an iterator over each Split in this Node.

pub fn pane_regions( &self, spacing: f32, min_size: f32, bounds: Size, ) -> BTreeMap<Pane, Rectangle>

Returns the rectangular region for each Pane in the Node given the spacing between panes and the total available space.

pub fn split_regions( &self, spacing: f32, min_size: f32, bounds: Size, ) -> BTreeMap<Split, (Axis, Rectangle, f32)>

Returns the axis, rectangular region, and ratio for each Split in the Node given the spacing between panes and the total available space.