TitleBar

Struct TitleBar 

pub struct TitleBar<'a, Message, Theme = Theme, Renderer = Renderer>
where Theme: Catalog, Renderer: Renderer,
{ /* private fields */ }
The title bar of a Pane.

Implementations

Source

impl<'a, Message, Theme, Renderer> TitleBar<'a, Message, Theme, Renderer>
where Theme: Catalog, Renderer: Renderer,

pub fn new(content: impl Into<Element<'a, Message, Theme, Renderer>>) -> Self

Creates a new TitleBar with the given content.

pub fn controls( self, controls: impl Into<Controls<'a, Message, Theme, Renderer>>, ) -> Self

Sets the controls of the TitleBar.

pub fn padding<P: Into<Padding>>(self, padding: P) -> Self

Sets the Padding of the TitleBar.

pub fn always_show_controls(self) -> Self

Sets whether or not the controls attached to this TitleBar are always visible.

By default, the controls are only visible when the Pane of this TitleBar is hovered.

pub fn style(self, style: impl Fn(&Theme) -> Style + 'a) -> Self
where Theme::Class<'a>: From<StyleFn<'a, Theme>>,

Sets the style of the TitleBar.

pub fn class(self, class: impl Into<Theme::Class<'a>>) -> Self

Available on crate feature advanced only.

Sets the style class of the TitleBar.

Source

impl<Message, Theme, Renderer> TitleBar<'_, Message, Theme, Renderer>
where Theme: Catalog, Renderer: Renderer,

pub fn draw( &self, tree: &Tree, renderer: &mut Renderer, theme: &Theme, inherited_style: &Style, layout: Layout<'_>, cursor: Cursor, viewport: &Rectangle, show_controls: bool, )

Draws the TitleBar with the provided Renderer and Layout.

pub fn is_over_pick_area( &self, layout: Layout<'_>, cursor_position: Point, ) -> bool

Returns whether the mouse cursor is over the pick area of the TitleBar or not.

The whole TitleBar is a pick area, except its controls.