Icon

Struct Icon 

pub struct Icon<Font> {
    pub font: Font,
    pub code_point: char,
    pub size: Option<Pixels>,
    pub line_height: LineHeight,
    pub shaping: Shaping,
}
The icon of a Handle.

Fields

font: Font

Font that will be used to display the code_point,

code_point: char

The unicode code point that will be used as the icon.

size: Option<Pixels>

Font size of the content.

line_height: LineHeight

Line height of the content.

shaping: Shaping

The shaping strategy of the icon.