Module iced_widget::qr_code
source · Available on crate feature
qr_code only.Expand description
Encode and display information in a QR code.
Structs
- The appearance of a QR code.
- The data of a
QRCode. - A type of matrix barcode consisting of squares arranged in a grid which can be read by an imaging device, such as a camera.
Enums
- The error correction level.
- The size of a
QRCode.
Traits
- A set of rules that dictate the style of a QR code.