pub enum ErrorCorrection {
Low,
Medium,
Quartile,
High,
}Available on crate feature
qr_code only.Expand description
The error correction level.
It controls the amount of data that can be damaged while still being able to recover the original information.
A higher error correction level allows for more corrupted data.
Variants
Low
Low error correction. 7% of the data can be restored.
Medium
Medium error correction. 15% of the data can be restored.
Quartile
Quartile error correction. 25% of the data can be restored.
High
High error correction. 30% of the data can be restored.