pub struct QRCode<'a, Theme = Theme>where
Theme: Catalog,{ /* private fields */ }Available on crate feature
qr_code only.Expand description
A type of matrix barcode consisting of squares arranged in a grid which can be read by an imaging device, such as a camera.
Example
use iced::widget::qr_code;
struct State {
data: qr_code::Data,
}
#[derive(Debug, Clone)]
enum Message {
// ...
}
fn view(state: &State) -> Element<'_, Message> {
qr_code(&state.data).into()
}Implementations
Sourceimpl<'a, Theme> QRCode<'a, Theme>where
Theme: Catalog,
impl<'a, Theme> QRCode<'a, Theme>where
Theme: Catalog,
Sourcepub fn cell_size(self, cell_size: impl Into<Pixels>) -> Self
pub fn cell_size(self, cell_size: impl Into<Pixels>) -> Self
Sets the size of the squares of the grid cell of the QRCode.
Sourcepub fn total_size(self, total_size: impl Into<Pixels>) -> Self
pub fn total_size(self, total_size: impl Into<Pixels>) -> Self
Sets the size of the entire QRCode.