Radio

Struct Radio 

pub struct Radio<'a, Message, Theme = Theme, Renderer = Renderer>
where Theme: Catalog, Renderer: Renderer,
{ /* private fields */ }
A circular button representing a choice.

Example

use iced::widget::{column, radio};

struct State {
   selection: Option<Choice>,
}

#[derive(Debug, Clone, Copy)]
enum Message {
    RadioSelected(Choice),
}

#[derive(Debug, Clone, Copy, PartialEq, Eq)]
enum Choice {
    A,
    B,
    C,
    All,
}

fn view(state: &State) -> Element<'_, Message> {
    let a = radio(
        "A",
        Choice::A,
        state.selection,
        Message::RadioSelected,
    );

    let b = radio(
        "B",
        Choice::B,
        state.selection,
        Message::RadioSelected,
    );

    let c = radio(
        "C",
        Choice::C,
        state.selection,
        Message::RadioSelected,
    );

    let all = radio(
        "All of the above",
        Choice::All,
        state.selection,
        Message::RadioSelected
    );

    column![a, b, c, all].into()
}

Implementations

Source

impl<'a, Message, Theme, Renderer> Radio<'a, Message, Theme, Renderer>
where Message: Clone, Theme: Catalog, Renderer: Renderer,

pub const DEFAULT_SIZE: f32 = 16f32

The default size of a Radio button.

pub const DEFAULT_SPACING: f32 = 8f32

The default spacing of a Radio button.

pub fn new<F, V>( label: impl Into<String>, value: V, selected: Option<V>, f: F, ) -> Self
where V: Eq + Copy, F: FnOnce(V) -> Message,

Creates a new Radio button.

It expects:

  • the value related to the Radio button
  • the label of the Radio button
  • the current selected value
  • a function that will be called when the Radio is selected. It receives the value of the radio and must produce a Message.
pub fn size(self, size: impl Into<Pixels>) -> Self

Sets the size of the Radio button.

pub fn width(self, width: impl Into<Length>) -> Self

Sets the width of the Radio button.

pub fn spacing(self, spacing: impl Into<Pixels>) -> Self

Sets the spacing between the Radio button and the text.

pub fn text_size(self, text_size: impl Into<Pixels>) -> Self

Sets the text size of the Radio button.

pub fn text_line_height(self, line_height: impl Into<LineHeight>) -> Self

Sets the text text::LineHeight of the Radio button.

pub fn text_shaping(self, shaping: Shaping) -> Self

Sets the text::Shaping strategy of the Radio button.

pub fn text_wrapping(self, wrapping: Wrapping) -> Self

Sets the text::Wrapping strategy of the Radio button.

pub fn font(self, font: impl Into<Renderer::Font>) -> Self

Sets the text font of the Radio button.

pub fn style(self, style: impl Fn(&Theme, Status) -> Style + 'a) -> Self
where Theme::Class<'a>: From<StyleFn<'a, Theme>>,

Sets the style of the Radio button.

pub fn class(self, class: impl Into<Theme::Class<'a>>) -> Self

Available on crate feature advanced only.

Sets the style class of the Radio button.