Row

Struct Row 

pub struct Row<'a, Message, Theme = Theme, Renderer = Renderer> { /* private fields */ }
A container that distributes its contents horizontally.

Example

use iced::widget::{button, row};

#[derive(Debug, Clone)]
enum Message {
    // ...
}

fn view(state: &State) -> Element<'_, Message> {
    row![
        "I am to the left!",
        button("I am in the middle!"),
        "I am to the right!",
    ].into()
}

Implementations

Source

impl<'a, Message, Theme, Renderer> Row<'a, Message, Theme, Renderer>
where Renderer: Renderer,

pub fn new() -> Self

Creates an empty Row.

pub fn with_capacity(capacity: usize) -> Self

Creates a Row with the given capacity.

pub fn with_children( children: impl IntoIterator<Item = Element<'a, Message, Theme, Renderer>>, ) -> Self

Creates a Row with the given elements.

pub fn from_vec(children: Vec<Element<'a, Message, Theme, Renderer>>) -> Self

Creates a Row from an already allocated Vec.

Keep in mind that the Row will not inspect the Vec, which means it won’t automatically adapt to the sizing strategy of its contents.

If any of the children have a Length::Fill strategy, you will need to call Row::width or Row::height accordingly.

pub fn spacing(self, amount: impl Into<Pixels>) -> Self

Sets the horizontal spacing between elements.

Custom margins per element do not exist in iced. You should use this method instead! While less flexible, it helps you keep spacing between elements consistent.

pub fn padding<P: Into<Padding>>(self, padding: P) -> Self

Sets the Padding of the Row.

pub fn width(self, width: impl Into<Length>) -> Self

Sets the width of the Row.

pub fn height(self, height: impl Into<Length>) -> Self

Sets the height of the Row.

pub fn align_y(self, align: impl Into<Vertical>) -> Self

Sets the vertical alignment of the contents of the Row .

pub fn clip(self, clip: bool) -> Self

Sets whether the contents of the Row should be clipped on overflow.

pub fn push( self, child: impl Into<Element<'a, Message, Theme, Renderer>>, ) -> Self

Adds an Element to the Row.

pub fn extend( self, children: impl IntoIterator<Item = Element<'a, Message, Theme, Renderer>>, ) -> Self

Extends the Row with the given children.

pub fn wrap(self) -> Wrapping<'a, Message, Theme, Renderer>

Turns the Row into a Wrapping row.

The original alignment of the Row is preserved per row wrapped.