Wrapping

Struct Wrapping 

pub struct Wrapping<'a, Message, Theme = Theme, Renderer = Renderer> { /* private fields */ }
A Row that wraps its contents.

Create a Row first, and then call Row::wrap to obtain a Row that wraps its contents.

The original alignment of the Row is preserved per row wrapped.

Implementations

Source

impl<Message, Theme, Renderer> Wrapping<'_, Message, Theme, Renderer>

pub fn vertical_spacing(self, amount: impl Into<Pixels>) -> Self

Sets the vertical spacing between lines.

pub fn align_x(self, align_x: impl Into<Horizontal>) -> Self

Sets the horizontal alignment of the wrapping Row.