FillMode

Enum FillMode 

pub enum FillMode {
    Full,
    Percent(f32),
    Padded(u16),
    AsymmetricPadding(u16, u16),
}
The fill mode of a rule.

Variants



Full

Fill the whole length of the container.



Percent(f32)

Fill a percent of the length of the container. The rule will be centered in that container.

The range is [0.0, 100.0].



Padded(u16)

Uniform offset from each end, length units.



AsymmetricPadding(u16, u16)

Different offset on each end of the rule, length units. First = top or left.

Implementations

Source

impl FillMode

pub fn fill(&self, space: f32) -> (f32, f32)

Return the starting offset and length of the rule.

  • space - The space to fill.
Returns
  • (starting_offset, length)