Status

Enum Status 

pub enum Status {
    Active {
        is_horizontal_scrollbar_disabled: bool,
        is_vertical_scrollbar_disabled: bool,
    },
    Hovered {
        is_horizontal_scrollbar_hovered: bool,
        is_vertical_scrollbar_hovered: bool,
        is_horizontal_scrollbar_disabled: bool,
        is_vertical_scrollbar_disabled: bool,
    },
    Dragged {
        is_horizontal_scrollbar_dragged: bool,
        is_vertical_scrollbar_dragged: bool,
        is_horizontal_scrollbar_disabled: bool,
        is_vertical_scrollbar_disabled: bool,
    },
}
The possible status of a Scrollable.

Variants



Active

The Scrollable can be interacted with.

Fields

is_horizontal_scrollbar_disabled: bool

Whether or not the horizontal scrollbar is disabled meaning the content isn’t overflowing.

is_vertical_scrollbar_disabled: bool

Whether or not the vertical scrollbar is disabled meaning the content isn’t overflowing.



Hovered

The Scrollable is being hovered.

Fields

is_horizontal_scrollbar_hovered: bool

Indicates if the horizontal scrollbar is being hovered.

is_vertical_scrollbar_hovered: bool

Indicates if the vertical scrollbar is being hovered.

is_horizontal_scrollbar_disabled: bool

Whether or not the horizontal scrollbar is disabled meaning the content isn’t overflowing.

is_vertical_scrollbar_disabled: bool

Whether or not the vertical scrollbar is disabled meaning the content isn’t overflowing.



Dragged

The Scrollable is being dragged.

Fields

is_horizontal_scrollbar_dragged: bool

Indicates if the horizontal scrollbar is being dragged.

is_vertical_scrollbar_dragged: bool

Indicates if the vertical scrollbar is being dragged.

is_horizontal_scrollbar_disabled: bool

Whether or not the horizontal scrollbar is disabled meaning the content isn’t overflowing.

is_vertical_scrollbar_disabled: bool

Whether or not the vertical scrollbar is disabled meaning the content isn’t overflowing.