AutoScroll

Struct AutoScroll 

pub struct AutoScroll {
    pub background: Background,
    pub border: Border,
    pub shadow: Shadow,
    pub icon: Color,
}
The appearance of the autoscroll overlay of a scrollable.

Fields

background: Background

The Background of the AutoScroll overlay.

border: Border

The Border of the AutoScroll overlay.

shadow: Shadow

Thje Shadow of the AutoScroll overlay.

icon: Color

The Color for the arrow icons of the AutoScroll overlay.