Scrollbar

Struct Scrollbar 

pub struct Scrollbar { /* private fields */ }
A scrollbar within a Scrollable.

Implementations

Source

impl Scrollbar

pub fn new() -> Self

Creates new Scrollbar for use in a Scrollable.

pub fn hidden() -> Self

Create a Scrollbar with zero width to allow a Scrollable to scroll without a visible scroller.

pub fn width(self, width: impl Into<Pixels>) -> Self

Sets the scrollbar width of the Scrollbar .

pub fn margin(self, margin: impl Into<Pixels>) -> Self

Sets the scrollbar margin of the Scrollbar .

pub fn scroller_width(self, scroller_width: impl Into<Pixels>) -> Self

Sets the scroller width of the Scrollbar .

pub fn anchor(self, alignment: Anchor) -> Self

Sets the Anchor of the Scrollbar .

pub fn spacing(self, spacing: impl Into<Pixels>) -> Self

Sets whether the Scrollbar should be embedded in the Scrollable, using the given spacing between itself and the contents.

An embedded Scrollbar will always be displayed, will take layout space, and will not float over the contents.