pub struct Action<Message> { /* private fields */ }Expand description
A runtime action that can be performed by some widgets.
Implementations
Sourceimpl<Message> Action<Message>
impl<Message> Action<Message>
Sourcepub fn publish(message: Message) -> Self
pub fn publish(message: Message) -> Self
Creates a new Action that publishes the given Message for
the application to handle.
Publishing a Message always produces a redraw.
Sourcepub fn request_redraw() -> Self
pub fn request_redraw() -> Self
Creates a new Action that requests a redraw to happen as
soon as possible; without publishing any Message.
Sourcepub fn request_redraw_at(at: Instant) -> Self
pub fn request_redraw_at(at: Instant) -> Self
Sourcepub fn and_capture(self) -> Self
pub fn and_capture(self) -> Self
Marks the Action as “capturing”. See Self::capture.
Sourcepub fn into_inner(self) -> (Option<Message>, RedrawRequest, Status)
pub fn into_inner(self) -> (Option<Message>, RedrawRequest, Status)
Converts the Action into its internal parts.
This method is meant to be used by runtimes, libraries, or internal widget implementations.