pub struct Svg<'a, Theme = Theme>where
Theme: Catalog,{ /* private fields */ }Available on crate feature
svg only.Expand description
A vector graphics image.
An Svg image resizes smoothly without losing any quality.
Svg images can have a considerable rendering cost when resized,
specially when they are complex.
Example
use iced::widget::svg;
enum Message {
// ...
}
fn view(state: &State) -> Element<'_, Message> {
svg("tiger.svg").into()
}Implementations
Sourceimpl<'a, Theme> Svg<'a, Theme>where
Theme: Catalog,
impl<'a, Theme> Svg<'a, Theme>where
Theme: Catalog,
Sourcepub fn from_path(path: impl Into<PathBuf>) -> Self
pub fn from_path(path: impl Into<PathBuf>) -> Self
Creates a new Svg that will display the contents of the file at the
provided path.
Sourcepub fn content_fit(self, content_fit: ContentFit) -> Self
pub fn content_fit(self, content_fit: ContentFit) -> Self
Sets the ContentFit of the Svg.
Defaults to ContentFit::Contain
Sourcepub fn style(self, style: impl Fn(&Theme, Status) -> Style + 'a) -> Self
pub fn style(self, style: impl Fn(&Theme, Status) -> Style + 'a) -> Self
Sets the style of the Svg.
Sourcepub fn class(self, class: impl Into<Theme::Class<'a>>) -> Self
Available on crate feature advanced only.
pub fn class(self, class: impl Into<Theme::Class<'a>>) -> Self
advanced only.Sets the style class of the Svg.