pub struct Style {
pub separator_x: Background,
pub separator_y: Background,
}Expand description
The appearance of a Table.
Fields
separator_x: BackgroundThe background color of the horizontal line separator between cells.
separator_y: BackgroundThe background color of the vertical line separator between cells.