Table

Struct Table 

pub struct Table<'a, Message, Theme = Theme, Renderer = Renderer>
where Theme: Catalog,
{ /* private fields */ }
A grid-like visual representation of data distributed in columns and rows.

Implementations

Source

impl<'a, Message, Theme, Renderer> Table<'a, Message, Theme, Renderer>
where Theme: Catalog, Renderer: Renderer,

pub fn new<'b, T>( columns: impl IntoIterator<Item = Column<'a, 'b, T, Message, Theme, Renderer>>, rows: impl IntoIterator<Item = T>, ) -> Self
where T: Clone,

Creates a new Table with the given columns and rows.

Columns can be created using the column() function, while rows can be any iterator over some data type T.

pub fn width(self, width: impl Into<Length>) -> Self

Sets the width of the Table.

pub fn padding(self, padding: impl Into<Pixels>) -> Self

Sets the padding of the cells of the Table.

pub fn padding_x(self, padding: impl Into<Pixels>) -> Self

Sets the horizontal padding of the cells of the Table.

pub fn padding_y(self, padding: impl Into<Pixels>) -> Self

Sets the vertical padding of the cells of the Table.

pub fn separator(self, separator: impl Into<Pixels>) -> Self

Sets the thickness of the line separator between the cells of the Table.

pub fn separator_x(self, separator: impl Into<Pixels>) -> Self

Sets the thickness of the horizontal line separator between the cells of the Table.

pub fn separator_y(self, separator: impl Into<Pixels>) -> Self

Sets the thickness of the vertical line separator between the cells of the Table.