Module iced_widget::text

source ·
Draw and interact with text.

Structs

  • The apperance of some text.
  • The internal state of a [Text] widget.

Enums

  • The height of a line of text in a paragraph.
  • The shaping strategy of some text.

Traits

Functions

  • Draws text using the same logic as the [Text] widget.
  • Produces the [layout::Node] of a [Text] widget.

Type Aliases