Content

Struct Content 

pub struct Content<R = Renderer>(/* private fields */)
where
    R: Renderer;
The content of a TextEditor.

Implementations

Source

impl<R> Content<R>
where R: Renderer,

pub fn new() -> Self

Creates an empty Content.

pub fn with_text(text: &str) -> Self

Creates a Content with the given text.

pub fn perform(&mut self, action: Action)

Performs an Action on the Content.

pub fn move_to(&mut self, cursor: Cursor)

Moves the current cursor to reflect the given one.

pub fn cursor(&self) -> Cursor

Returns the current cursor position of the Content.

pub fn line_count(&self) -> usize

Returns the amount of lines of the Content.

pub fn line(&self, index: usize) -> Option<Line<'_>>

Returns the text of the line at the given index, if it exists.

pub fn lines(&self) -> impl Iterator<Item = Line<'_>>

Returns an iterator of the text of the lines in the Content.

pub fn text(&self) -> String

Returns the text of the Content.

pub fn selection(&self) -> Option<String>

Returns the selected text of the Content.

pub fn line_ending(&self) -> Option<LineEnding>

Returns the kind of LineEnding used for separating lines in the Content.

pub fn is_empty(&self) -> bool

Returns whether or not the the Content is empty.