pub struct Style {
pub background: Background,
pub border: Border,
pub placeholder: Color,
pub value: Color,
pub selection: Color,
pub shadow: Shadow,
}Expand description
The appearance of a text input.
Fields
background: BackgroundThe Background of the text input.
border: BorderThe Border of the text input.
placeholder: ColorThe Color of the placeholder of the text input.
value: ColorThe Color of the value of the text input.
selection: ColorThe Color of the selection of the text input.
shadow: ShadowThe Shadow of the text editor.