pub struct Icon<Font> {
pub font: Font,
pub code_point: char,
pub size: Option<Pixels>,
pub spacing: f32,
pub side: Side,
}Expand description
The content of the Icon.
Fields
font: FontThe font that will be used to display the code_point.
code_point: charThe unicode code point that will be used as the icon.
size: Option<Pixels>The font size of the content.
spacing: f32side: SideTrait Implementations