pub struct Value { /* private fields */ }Expand description
The value of a TextInput.
Implementations
Sourceimpl Value
impl Value
Sourcepub fn previous_start_of_word(&self, index: usize) -> usize
pub fn previous_start_of_word(&self, index: usize) -> usize
Returns the position of the previous start of a word from the given
grapheme index.
Sourcepub fn next_end_of_word(&self, index: usize) -> usize
pub fn next_end_of_word(&self, index: usize) -> usize
Returns the position of the next end of a word from the given grapheme
index.
Sourcepub fn select(&self, start: usize, end: usize) -> Self
pub fn select(&self, start: usize, end: usize) -> Self
Returns a new Value containing the graphemes from start until the
given end.
Sourcepub fn until(&self, index: usize) -> Self
pub fn until(&self, index: usize) -> Self
Returns a new Value containing the graphemes until the given
index.
Sourcepub fn insert(&mut self, index: usize, c: char)
pub fn insert(&mut self, index: usize, c: char)
Inserts a new char at the given grapheme index.
Sourcepub fn insert_many(&mut self, index: usize, value: Value)
pub fn insert_many(&mut self, index: usize, value: Value)
Inserts a bunch of graphemes at the given grapheme index.
Sourcepub fn remove_many(&mut self, start: usize, end: usize)
pub fn remove_many(&mut self, start: usize, end: usize)
Removes the graphemes from start to end.