pub struct Style {
pub background: Background,
pub background_border_width: f32,
pub background_border_color: Color,
pub foreground: Background,
pub foreground_border_width: f32,
pub foreground_border_color: Color,
pub text_color: Option<Color>,
pub border_radius: Option<Radius>,
pub padding_ratio: f32,
}Expand description
The appearance of a toggler.
Fields
background: BackgroundThe background Color of the toggler.
background_border_width: f32The width of the background border of the toggler.
background_border_color: ColorThe Color of the background border of the toggler.
foreground: BackgroundThe foreground Color of the toggler.
foreground_border_width: f32The width of the foreground border of the toggler.
foreground_border_color: ColorThe Color of the foreground border of the toggler.
text_color: Option<Color>The text Color of the toggler.
border_radius: Option<Radius>The border radius of the toggler.
If None, the toggler will be perfectly round.
padding_ratio: f32The ratio of separation between the background and the toggle in relative height.