Use the built-in widgets or create your own.
Re-exports
pub use button::Button;pub use checkbox::Checkbox;pub use column::Column;pub use combo_box::ComboBox;pub use container::Container;pub use mouse_area::MouseArea;pub use pane_grid::PaneGrid;pub use pick_list::PickList;pub use progress_bar::ProgressBar;pub use radio::Radio;pub use row::Row;pub use rule::Rule;pub use scrollable::Scrollable;pub use slider::Slider;pub use space::Space;pub use stack::Stack;pub use text::Text;pub use text_editor::TextEditor;pub use text_input::TextInput;pub use themer::Themer;pub use toggler::Toggler;pub use tooltip::Tooltip;pub use vertical_slider::VerticalSlider;pub use shader::Shader;wgpupub use svg::Svg;svgpub use image::Image;imagepub use canvas::Canvas;canvaspub use qr_code::QRCode;qr_codepub use iced_renderer as renderer;pub use iced_renderer::graphics;pub use iced_runtime as runtime;pub use iced_runtime::core;
Modules
- button
- Buttons allow your users to perform actions by pressing them.
- canvas
canvas - Canvases can be leveraged to draw interactive 2D graphics.
- checkbox
- Checkboxes can be used to let users make binary choices.
- combo_
box - Combo boxes display a dropdown list of searchable and selectable options.
- container
- Containers let you align a widget inside their boundaries.
- image
image - Images display raster graphics in different formats (PNG, JPG, etc.).
- keyed
- Keyed widgets can provide hints to ensure continuity.
- markdown
markdown - Markdown widgets can parse and display Markdown.
- overlay
- Display interactive elements on top of other widgets.
- pane_
grid - Pane grids let your users split regions of your application and organize layout dynamically.
- pick_
list - Pick lists display a dropdown list of selectable options.
- progress_
bar - Progress bars visualize the progression of an extended computer operation, such as a download, file transfer, or installation.
- qr_code
qr_code - QR codes display information in a type of two-dimensional matrix barcode.
- radio
- Radio buttons let users choose a single option from a bunch of options.
- rule
- Rules divide space horizontally or vertically.
- scrollable
- Scrollables let users navigate an endless amount of content with a scrollbar.
- shader
wgpu - A custom shader widget for wgpu applications.
- slider
- Sliders let users set a value by moving an indicator.
- svg
svg - Svg widgets display vector graphics in your application.
- text
- Draw and interact with text.
- text_
editor - Text editors display a multi-line text input for text editing.
- text_
input - Text inputs display fields that can be filled with text.
- theme
- Use the built-in theme and styles.
- toggler
- Togglers let users make binary choices by toggling a switch.
- tooltip
- Tooltips display a hint of information over some element when hovered.
- vertical_
slider - Sliders let users set a value by moving an indicator.
Macros
- column
- Creates a [
Column] with the given children. - keyed_
column - Creates a keyed
Columnwith the given children. - rich_
text - Creates some
Richtext with the given spans. - row
- Creates a [
Row] with the given children. - stack
- Creates a
Stackwith the given children. - text
- Creates a new
Textwidget with the provided content.
Structs
- Lazy
lazy - A widget that only rebuilds its contents when necessary.
- Responsive
lazy - A widget that is aware of its dimensions.
Enums
- Theme
- A built-in theme.
Traits
- Component
Deprecated lazy - A reusable, custom widget that uses The Elm Architecture.
Functions
- button
- Creates a new
Buttonwith the provided content. - canvas
canvas - Creates a new
Canvas. - center
- Creates a new
Containerthat fills all the available space and centers its contents inside. - checkbox
- Creates a new
Checkbox. - column
- Creates a new [
Column] with the given children. - combo_
box - Creates a new
ComboBox. - component
Deprecated lazy - Turns an implementor of
Componentinto anElementthat can be embedded in any application. - container
- Creates a new
Containerwith the provided content. - focus_
next - Focuses the next focusable widget.
- focus_
previous - Focuses the previous focusable widget.
- horizontal_
rule - Creates a horizontal
Rulewith the given height. - horizontal_
space - Creates a new [
Space] widget that fills the available horizontal space. - hover
- Displays a widget on top of another one, only when the base widget is hovered.
- iced
svg - Creates an
Elementthat displays the iced logo with the giventext_size. - image
image - Creates a new
Image. - keyed_
column - Creates a new
keyed::Columnfrom an iterator of elements. - lazy
lazy - Creates a new
Lazywidget with the given dataDependencyand a closure that can turn this data into a widget tree. - markdown
markdown - Display a bunch of Markdown items.
- mouse_
area - A container intercepting mouse events.
- opaque
- Wraps the given widget and captures any mouse button presses inside the bounds of the widget—effectively making it opaque.
- pane_
grid - Creates a
PaneGridwith the givenpane_grid::Stateand view function. - pick_
list - Creates a new
PickList. - progress_
bar - Creates a new
ProgressBar. - qr_code
qr_code - Creates a new
QRCodewidget from the givenData. - radio
- Creates a new
Radio. - responsive
lazy - Creates a new
Responsivewidget with a closure that produces its contents. - rich_
text - Creates a new
Richtext widget with the provided spans. - row
- Creates a new [
Row] from an iterator. - scrollable
- Creates a new
Scrollablewith the provided content. - shader
wgpu - Creates a new
Shader. - slider
- Creates a new
Slider. - span
- Creates a new
Spanof text with the provided content. - stack
- Creates a new
Stackwith the given children. - svg
svg - Creates a new
Svgwidget from the givenHandle. - text
- Creates a new
Textwidget with the provided content. - text_
editor - Creates a new
TextEditor. - text_
input - Creates a new
TextInput. - themer
- A widget that applies any
Themeto its contents. - toggler
- Creates a new
Toggler. - tooltip
- Creates a new
Tooltipfor the provided content with the givenElementandtooltip::Position. - value
- Creates a new
Textwidget that displays the provided value. - vertical_
rule - Creates a vertical
Rulewith the given width. - vertical_
slider - Creates a new
VerticalSlider. - vertical_
space - Creates a new [
Space] widget that fills the available vertical space.