pub struct Content { /* private fields */ }Available on crate feature
markdown only.Expand description
A bunch of Markdown that has been parsed.
Implementations
Sourceimpl Content
impl Content
Sourcepub fn code_theme(self, theme: Theme) -> Self
Available on crate feature highlighter only.
pub fn code_theme(self, theme: Theme) -> Self
highlighter only.Sets the syntax highlighting theme for code blocks.
This only has an effect when the highlighter feature is enabled.
Existing code blocks are not re-highlighted; call this before
push_str.
Sourcepub fn push_str(&mut self, markdown: &str)
pub fn push_str(&mut self, markdown: &str)
Pushes more Markdown into the Content; parsing incrementally!
This is specially useful when you have long streams of Markdown; like big files or potentially long replies.