pub enum Anchor {
Start,
End,
}Expand description
The anchor of the scroller of the Scrollable relative to its Viewport
on a given axis.
Variants
Start
Scroller is anchored to the start of the Viewport.
End
Content is aligned to the end of the Viewport.