pub struct AutoScroll {
pub background: Background,
pub border: Border,
pub shadow: Shadow,
pub icon: Color,
}Expand description
The appearance of the autoscroll overlay of a scrollable.
Fields
background: BackgroundThe Background of the AutoScroll overlay.
border: BorderThe Border of the AutoScroll overlay.
shadow: ShadowThje Shadow of the AutoScroll overlay.
icon: ColorThe Color for the arrow icons of the AutoScroll overlay.