pub struct Span<'a, Link = (), Font = Font> {
pub text: Cow<'a, str>,
pub size: Option<Pixels>,
pub line_height: Option<LineHeight>,
pub font: Option<Font>,
pub color: Option<Color>,
pub link: Option<Link>,
pub highlight: Option<Highlight>,
pub padding: Padding,
pub underline: bool,
pub strikethrough: bool,
}Expand description
A span of text.
Fields
text: Cow<'a, str>The Fragment of text.
size: Option<Pixels>line_height: Option<LineHeight>The LineHeight of the Span.
font: Option<Font>The font of the Span.
color: Option<Color>link: Option<Link>The link of the Span.
highlight: Option<Highlight>padding: Paddingunderline: boolWhether the Span should be underlined or not.
strikethrough: boolWhether the Span should be struck through or not.
Implementations
Sourceimpl<'a, Link, Font> Span<'a, Link, Font>
impl<'a, Link, Font> Span<'a, Link, Font>
Sourcepub fn new(fragment: impl IntoFragment<'a>) -> Span<'a, Link, Font>
pub fn new(fragment: impl IntoFragment<'a>) -> Span<'a, Link, Font>
Creates a new Span of text with the given text fragment.
Sourcepub fn line_height(
self,
line_height: impl Into<LineHeight>,
) -> Span<'a, Link, Font>
pub fn line_height( self, line_height: impl Into<LineHeight>, ) -> Span<'a, Link, Font>
Sets the LineHeight of the Span.
Sourcepub fn font_maybe(self, font: Option<impl Into<Font>>) -> Span<'a, Link, Font>
pub fn font_maybe(self, font: Option<impl Into<Font>>) -> Span<'a, Link, Font>
Sets the font of the Span, if any.
Sourcepub fn link_maybe(self, link: Option<impl Into<Link>>) -> Span<'a, Link, Font>
pub fn link_maybe(self, link: Option<impl Into<Link>>) -> Span<'a, Link, Font>
Sets the link of the Span, if any.
Sourcepub fn background(
self,
background: impl Into<Background>,
) -> Span<'a, Link, Font>
pub fn background( self, background: impl Into<Background>, ) -> Span<'a, Link, Font>
Sets the Background of the Span.
Sourcepub fn background_maybe(
self,
background: Option<impl Into<Background>>,
) -> Span<'a, Link, Font>
pub fn background_maybe( self, background: Option<impl Into<Background>>, ) -> Span<'a, Link, Font>
Sets the Background of the Span, if any.
Sourcepub fn padding(self, padding: impl Into<Padding>) -> Span<'a, Link, Font>
pub fn padding(self, padding: impl Into<Padding>) -> Span<'a, Link, Font>
It only affects the background and border of the
Span, currently.
Sourcepub fn underline(self, underline: bool) -> Span<'a, Link, Font>
pub fn underline(self, underline: bool) -> Span<'a, Link, Font>
Sets whether the Span should be underlined or not.
Sourcepub fn strikethrough(self, strikethrough: bool) -> Span<'a, Link, Font>
pub fn strikethrough(self, strikethrough: bool) -> Span<'a, Link, Font>
Sets whether the Span should be struck through or not.