Icon

Struct Icon 

pub struct Icon<Font> {
    pub font: Font,
    pub code_point: char,
    pub size: Option<Pixels>,
    pub spacing: f32,
    pub side: Side,
}
The content of the Icon.

Fields

font: Font

The font that will be used to display the code_point.

code_point: char

The unicode code point that will be used as the icon.

size: Option<Pixels>

The font size of the content.

spacing: f32

The spacing between the Icon and the text in a TextInput.

side: Side

The side of a TextInput where to display the Icon.