Value

Struct Value 

pub struct Value { /* private fields */ }
The value of a TextInput.

Implementations

Source

impl Value

pub fn new(string: &str) -> Self

Creates a new Value from a string slice.

pub fn is_empty(&self) -> bool

Returns whether the Value is empty or not.

A Value is empty when it contains no graphemes.

pub fn len(&self) -> usize

Returns the total amount of graphemes in the Value.

pub fn previous_start_of_word(&self, index: usize) -> usize

Returns the position of the previous start of a word from the given grapheme index.

pub fn next_end_of_word(&self, index: usize) -> usize

Returns the position of the next end of a word from the given grapheme index.

pub fn select(&self, start: usize, end: usize) -> Self

Returns a new Value containing the graphemes from start until the given end.

pub fn until(&self, index: usize) -> Self

Returns a new Value containing the graphemes until the given index.

pub fn insert(&mut self, index: usize, c: char)

Inserts a new char at the given grapheme index.

pub fn insert_many(&mut self, index: usize, value: Value)

Inserts a bunch of graphemes at the given grapheme index.

pub fn remove(&mut self, index: usize)

Removes the grapheme at the given index.

pub fn remove_many(&mut self, start: usize, end: usize)

Removes the graphemes from start to end.

pub fn secure(&self) -> Self

Returns a new Value with all its graphemes replaced with the dot (‘•’) character.