pub enum Position {
Top,
Bottom,
Left,
Right,
FollowCursor,
}Expand description
The position of the tooltip. Defaults to following the cursor.
Variants
Top
The tooltip will appear on the top of the widget.
Bottom
The tooltip will appear on the bottom of the widget.
Left
The tooltip will appear on the left of the widget.
Right
The tooltip will appear on the right of the widget.
FollowCursor
The tooltip will follow the cursor.