Tooltip

Struct Tooltip 

pub struct Tooltip<'a, Message, Theme = Theme, Renderer = Renderer>
where Theme: Catalog, Renderer: Renderer,
{ /* private fields */ }
An element to display a widget over another.

Example

use iced::widget::{container, tooltip};

enum Message {
    // ...
}

fn view(_state: &State) -> Element<'_, Message> {
    tooltip(
        "Hover me to display the tooltip!",
        container("This is the tooltip contents!")
            .padding(10)
            .style(container::rounded_box),
        tooltip::Position::Bottom,
    ).into()
}

Implementations

Source

impl<'a, Message, Theme, Renderer> Tooltip<'a, Message, Theme, Renderer>
where Theme: Catalog, Renderer: Renderer,

pub fn new( content: impl Into<Element<'a, Message, Theme, Renderer>>, tooltip: impl Into<Element<'a, Message, Theme, Renderer>>, position: Position, ) -> Self

Creates a new Tooltip.

pub fn gap(self, gap: impl Into<Pixels>) -> Self

Sets the gap between the content and its Tooltip.

pub fn padding(self, padding: impl Into<Pixels>) -> Self

Sets the padding of the Tooltip.

pub fn delay(self, delay: Duration) -> Self

Sets the delay before the Tooltip is shown.

Set to Duration::ZERO to be shown immediately.

pub fn snap_within_viewport(self, snap: bool) -> Self

Sets whether the Tooltip is snapped within the viewport.

pub fn style(self, style: impl Fn(&Theme) -> Style + 'a) -> Self
where Theme::Class<'a>: From<StyleFn<'a, Theme>>,

Sets the style of the Tooltip.

pub fn class(self, class: impl Into<Theme::Class<'a>>) -> Self

Available on crate feature advanced only.

Sets the style class of the Tooltip.